import React, { AnchorHTMLAttributes, FC, ReactNode } from 'react';
import * as atomic_router from 'atomic-router';
import { RouteParams, RouteInstance, RouteQuery, createHistoryRouter } from 'atomic-router';
import * as history from 'history';
import * as effector from 'effector';

declare type Props$1<Params extends RouteParams> = {
    to: RouteInstance<Params> | string;
    params?: Params;
    query?: RouteQuery;
    className?: string;
    activeClassName?: string;
    inactiveClassName?: string;
} & Exclude<AnchorHTMLAttributes<HTMLAnchorElement>, 'href'>;
declare function Link<Params extends RouteParams>({ to, params, query, className, activeClassName, inactiveClassName, ...props }: Props$1<Params>): JSX.Element;

declare type Props<Params extends RouteParams> = {
    route: RouteInstance<Params> | RouteInstance<Params>[];
    view: FC;
};
declare function Route<Params>({ route, view: Component }: Props<Params>): JSX.Element | null;

declare type Router = ReturnType<typeof createHistoryRouter>;
declare const RouterContext: React.Context<{
    $path: effector.Store<string>;
    $query: effector.Store<{}>;
    $activeRoutes: effector.Store<atomic_router.RouteInstance<any>[]>;
    $history: effector.Store<any>;
    setHistory: effector.Event<any>;
    push: effector.Effect<Pick<{
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, "path" | "params" | "query" | "method">, {
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, Error>;
    routes: {
        route: atomic_router.RouteInstance<any>;
        path: string;
    }[];
    routeNotFound: effector.Event<void>;
} | null>;
declare function RouterProvider({ router, children, }: {
    router: Router;
    children: ReactNode;
}): JSX.Element;
declare function useRouter(): {
    $path: effector.Store<string>;
    $query: effector.Store<{}>;
    $activeRoutes: effector.Store<atomic_router.RouteInstance<any>[]>;
    $history: effector.Store<any>;
    setHistory: effector.Event<any>;
    push: effector.Effect<Pick<{
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, "path" | "params" | "query" | "method">, {
        history: history.History;
        path: string;
        params: atomic_router.RouteParams;
        query: atomic_router.RouteQuery;
        method: "replace" | "push";
    }, Error>;
    routes: {
        route: atomic_router.RouteInstance<any>;
        path: string;
    }[];
    routeNotFound: effector.Event<void>;
};

declare const createRouteView: <Props>(route: RouteInstance<any> | RouteInstance<any>[], View: React.FC<Props>) => (props: Props) => JSX.Element | null;

declare const createRoutesView: (config: {
    routes: {
        route: RouteInstance<any> | RouteInstance<any>[];
        view: FC<any>;
    }[];
    notFound?: FC<any>;
}) => () => JSX.Element;

export { Link, Route, RouterContext, RouterProvider, createRouteView, createRoutesView, useRouter };
